require "states/gameplay_functions/levelloader.lua"

gameplay=Gamestate.new()

function gameplay:enter()
	--we don't want previous timers carrying over
	Timer.clear()

	--mouse movement detection
	mousey=love.mouse.getY()
	mousey_previous=mousey
	Timer.addPeriodic(1/30, function()
		mousey_previous=mousey
		mousey=love.mouse.getY()
	end)

	loadlevel("test.tilt")
	
	--other variables
	platform_active=0
end

function collision_add(shape1,shape2,collision)
	for a=1,numobjects do
		if (shape1=="ball" and shape2=="platform"..a) or (shape2=="ball" and shape1=="platform"..a) then
			platform_active=a
		elseif (shape1=="ball" and shape2=="spike"..a) or (shape2=="ball" and shape1=="spike"..a) then
			Gamestate.switch(gameplay)
		end
	end
	
	if (shape1=="ball" and shape2=="enemy") or (shape2=="ball" and shape1=="enemy") then Gamestate.switch(gameplay) end
end

function gameplay:update(dt)
	for a=1,numobjects do
		--rotate platforms
		if object[a]=="platform" then
			if platform_active==a and love.mouse.isDown("l") then
				if (mousey-mousey_previous)/10>5 then --limit platform rotation speed
					platform[a].body:setAngularVelocity(5)
				elseif (mousey-mousey_previous)/10<-5 then
					platform[a].body:setAngularVelocity(-5)
				else
					platform[a].body:setAngularVelocity((mousey-mousey_previous)/10)
				end
			else
				platform[a].body:setAngularVelocity(0)
			end
		elseif object[a]=="jet" then
			--update jet particle systems
			jet[a].particle:update(dt)

			--jet physics
			if jet_table[a].dir=="left" and ball.body:getX()<tonumber(xpos[a]) and ball.body:getY()>tonumber(ypos[a])-100 and ball.body:getY()<tonumber(ypos[a])+100 then
				ball.body:applyForce(-5000/(math.sqrt((xpos[a]-ball.body:getX())^2+(ypos[a]-ball.body:getY())^2)),0,0,0) --yay distance formula!
			elseif jet_table[a].dir=="right" and ball.body:getX()>tonumber(xpos[a]) and ball.body:getY()>tonumber(ypos[a])-100 and ball.body:getY()<tonumber(ypos[a])+100 then
				ball.body:applyForce(5000/(math.sqrt((ball.body:getX()-xpos[a])^2+(ypos[a]-ball.body:getY())^2)),0,0,0)
			elseif jet_table[a].dir=="up" and ball.body:getY()<tonumber(ypos[a]) and ball.body:getX()>tonumber(xpos[a])-100 and ball.body:getX()<tonumber(xpos[a])+100 then
				ball.body:applyForce(0,-5000/(math.sqrt((ypos[a]-ball.body:getY())^2+(xpos[a]-ball.body:getX())^2)),0,0)
			elseif jet_table[a].dir=="down" and ball.body:getY()>tonumber(ypos[a]) and ball.body:getX()>tonumber(xpos[a])-100 and ball.body:getX()<tonumber(xpos[a])+100 then
				ball.body:applyForce(0,5000/(math.sqrt((ball.body:getY()-ypos[a])^2+(xpos[a]-ball.body:getX())^2)),0,0)
			end

			--same for enemies
			for b=1,numobjects do
				if object[b]=="enemy" then
					if enemy[b].dead==0 then
						if jet_table[a].dir=="left" and enemy[b].body:getX()<tonumber(xpos[a]) and enemy[b].body:getY()>tonumber(ypos[a])-100 and enemy[b].body:getY()<tonumber(ypos[a])+100 then
							enemy[b].body:applyForce(-5000/(math.sqrt((xpos[a]-enemy[b].body:getX())^2+(ypos[a]-enemy[b].body:getY())^2)),0,0,0)
						elseif jet_table[a].dir=="right" and enemy[b].body:getX()>tonumber(xpos[a]) and enemy[b].body:getY()>tonumber(ypos[a])-100 and enemy[b].body:getY()<tonumber(ypos[a])+100 then
							enemy[b].body:applyForce(5000/(math.sqrt((enemy[b].body:getX()-xpos[a])^2+(ypos[a]-enemy[b].body:getY())^2)),0,0,0)
						elseif jet_table[a].dir=="up" and enemy[b].body:getY()<tonumber(ypos[a]) and enemy[b].body:getX()>tonumber(xpos[a])-100 and enemy[b].body:getX()<tonumber(xpos[a])+100 then
							enemy[b].body:applyForce(0,-5000/(math.sqrt((ypos[a]-enemy[b].body:getY())^2+(xpos[a]-enemy[b].body:getX())^2)),0,0)
						elseif jet_table[a].dir=="down" and enemy[b].body:getY()>tonumber(ypos[a]) and enemy[b].body:getX()>tonumber(xpos[a])-100 and enemy[b].body:getX()<tonumber(xpos[a])+100 then
							enemy[b].body:applyForce(0,5000/(math.sqrt((enemy[b].body:getY()-ypos[a])^2+(xpos[a]-enemy[b].body:getX())^2)),0,0)
						end
					end
				end
			end
		elseif object[a]=="enemyspawn" then
			enemy_spawn[a].particle:update(dt)
		end
	end

	--check if ball goes off screen
	if ball.body:isFrozen() then Gamestate.switch(gameplay) end

	--check if enemies go off screen
	for a=1,numobjects do
		if object[a]=="enemy" then
			if enemy[a].body:getX()<-10 or enemy[a].body:getX()>810 or enemy[a].body:getY()>610 then enemy[a].dead=1 end
		end
	end

	world:update(dt)
end

function gameplay:keypressed(key)
	if key=="r" then Gamestate.switch(gameplay) end
end

function gameplay:draw()
--drawing function note: I could have made xpos and ypos local and gotten the coordinates of the objects using body:getX and body:getY, but that would require more typing
	for a=1,numobjects do
		if object[a]=="wall" then
			love.graphics.setColor(255,255,255,255)
			love.graphics.rectangle("fill",xpos[a]-15,ypos[a]-15,30,30)
		elseif object[a]=="ball" then
			love.graphics.setColor(255,255,255,255)
			love.graphics.circle("fill",ball.body:getX(),ball.body:getY(),15,15)
		elseif object[a]=="platform" then
			for b=1,#platform[a].shape do
				if platform_active==a then	
					love.graphics.setColor(255,0,0,255)
				else
					love.graphics.setColor(255,255,255,255)
				end
				love.graphics.polygon("fill",platform[a].shape[b]:getPoints())
			end
		elseif object[a]=="spring" then
			love.graphics.setColor(0,0,255,255)
			love.graphics.rectangle("fill",xpos[a]-15,ypos[a]-15,30,30)
		elseif object[a]=="spike" then
			love.graphics.setColor(255,0,0,255)
			love.graphics.rectangle("fill",xpos[a]-15,ypos[a]-15,30,30)
		elseif object[a]=="jet" then
			love.graphics.draw(jet[a].particle,xpos[a],ypos[a])
		elseif object[a]=="enemy" then
			love.graphics.draw(image_enemy,enemy[a].body:getX(),enemy[a].body:getY(),enemy[a].body:getAngle(),1,1,16,16)
		elseif object[a]=="enemyspawn" then
			love.graphics.draw(enemy_spawn[a].particle,xpos[a],ypos[a])
		end
	end

	if message then
		love.graphics.setColor(255,255,255,255)
		love.graphics.print(message,0,0)
	end
end
