function loadlevel(path)
	--we need these tables to create the objects later
	xpos={}
	ypos={}
	object={}
	platform_table={} --used so we don't overwrite object[a]
	jet_table={}
	enemy_spawn_table={}
	--open the file
	local file=love.filesystem.newFile(path)
	file:open("r")
	a=0
	--find x, y, and type for each object
	for line in file:lines() do
		a=a+1
		xpos[a]=line:sub(1,line:find(",")-1)
		line=line:sub(line:find(",")+1,line:len()) --delete just-read parameter
		ypos[a]=line:sub(1,line:find(",")-1)
		line=line:sub(line:find(",")+1,line:len())
		object[a]=line:sub(1,line:find(",")-1)
		
		--platform-specific parameters
		if object[a]=="platform" then
			line=line:sub(line:find(",")+1,line:len())
			b=0
			platform_table[a]={}
			while true do --for some reason "while not line="" do" didn't work
				b=b+1
				platform_table[a][b]={}
				platform_table[a][b].x=line:sub(1,line:find(",")-1)
				line=line:sub(line:find(",")+1,line:len())
				platform_table[a][b].y=line:sub(1,line:find(",")-1)
				line=line:sub(line:find(",")+1,line:len())
				platform_table[a][b].len=line:sub(1,line:find(",")-1)
				line=line:sub(line:find(",")+1,line:len())
				platform_table[a][b].rot=line:sub(1,line:find(",")-1)
				line=line:sub(line:find(",")+1,line:len())
				if line=="" then break end
			end
		end

		--jet-specific parameters
		if object[a]=="jet" then
			line=line:sub(line:find(",")+1,line:len())
			jet_table[a]={dir=line:sub(1,line:find(",")-1)}
		end

		--enemy spawner specific parameters
		if object[a]=="enemyspawn" then
			line=line:sub(line:find(",")+1,line:len())
			enemy_spawn_table[a]={time=line:sub(1,line:find(",")-1)}
		end
	end
	numobjects=a
	file:close()
	
	world=love.physics.newWorld(0,-600,800,600,0,500) --create world
	world:setCallbacks(collision_add,collision_persist,collision_remove,collision_result)
	
	--some tables
	wall={}
	platform={}
	spring={}
	spike={}
	jet={}
	enemy={}
	enemy_spawn={}
	
	--create physics objects
	for a=1,numobjects do
		if object[a]=="wall" then
			wall[a]={}
			wall[a].body=love.physics.newBody(world,xpos[a],ypos[a])
			wall[a].shape=love.physics.newRectangleShape(wall[a].body,0,0,30,30)
			wall[a].shape:setFriction(0)
		elseif object[a]=="ball" then
			ball={}
			ball.body=love.physics.newBody(world,xpos[a],ypos[a],1,0.01)
			ball.shape=love.physics.newCircleShape(ball.body,0,0,15)
			ball.shape:setData("ball")
		elseif object[a]=="platform" then
			platform[a]={}
			platform[a].body=love.physics.newBody(world,xpos[a],ypos[a],1)
			platform[a].anchor=love.physics.newBody(world,xpos[a],ypos[a])
			platform[a].joint=love.physics.newRevoluteJoint(platform[a].body,platform[a].anchor,xpos[a],ypos[a])
			platform[a].shape={}
			for b=1,#platform_table[a] do
				platform[a].shape[b]=love.physics.newRectangleShape(platform[a].body,platform_table[a][b].x,platform_table[a][b].y,platform_table[a][b].len,5,math.rad(platform_table[a][b].rot))
				platform[a].shape[b]:setData("platform"..a)
				platform[a].shape[b]:setFriction(0.2)
			end
		elseif object[a]=="spring" then
			spring[a]={}
			spring[a].body=love.physics.newBody(world,xpos[a],ypos[a])
			spring[a].shape=love.physics.newRectangleShape(spring[a].body,0,0,30,30)
			spring[a].shape:setRestitution(1)
			spring[a].shape:setFriction(0)
		elseif object[a]=="spike" then
			spike[a]={}
			spike[a].body=love.physics.newBody(world,xpos[a],ypos[a])
			spike[a].shape=love.physics.newRectangleShape(spike[a].body,0,0,30,30)
			spike[a].shape:setData("spike"..a)
		elseif object[a]=="jet" then
			jet[a]={body=love.physics.newBody(world,xpos[a],ypos[a]),particle=love.graphics.newParticleSystem(image_particle,100)}
			--edit our fancy particle system
			if jet_table[a].dir=="right" then jet[a].particle:setDirection(math.rad(0))
			elseif jet_table[a].dir=="up" then jet[a].particle:setDirection(math.rad(270))
			elseif jet_table[a].dir=="left" then jet[a].particle:setDirection(math.rad(180))
			elseif jet_table[a].dir=="down" then jet[a].particle:setDirection(math.rad(90)) end
			jet[a].particle:setColor(200,200,255,255,200,200,255,0)
			jet[a].particle:setSpread(math.rad(30))
			jet[a].particle:setSpeed(150,200)
			jet[a].particle:setParticleLife(3,3)
			jet[a].particle:setEmissionRate(15)
		elseif object[a]=="enemy" then
			enemy[a]={}
			enemy[a].body=love.physics.newBody(world,xpos[a],ypos[a],1,0.01)
			enemy[a].shape=love.physics.newCircleShape(enemy[a].body,0,0,15)
			enemy[a].shape:setData("enemy")
			enemy[a].dead=0
		elseif object[a]=="enemyspawn" then
			--another fancy particle system
			enemy_spawn[a]={particle=love.graphics.newParticleSystem(image_particle,50)}
			enemy_spawn[a].particle:setColor(255,0,0,255,255,0,0,0)
			enemy_spawn[a].particle:setSpread(math.rad(360))
			enemy_spawn[a].particle:setSpeed(25,25)
			enemy_spawn[a].particle:setParticleLife(1.5,1.5)
			enemy_spawn[a].particle:setEmissionRate(10)
			--and now for actually spawning enemies
			local enemycreated=0
			Timer.addPeriodic(enemy_spawn_table[a].time, function() --the following function reuses dead enemies
				for b=1,numobjects do
					if object[b]=="enemy" then
						if enemy[b].dead==1 then
							enemy[b]={}
							enemy[b].body=love.physics.newBody(world,xpos[a],ypos[a],1,0.01)
							enemy[b].shape=love.physics.newCircleShape(enemy[b].body,0,0,15)
							enemy[b].shape:setData("enemy")
							enemy[b].dead=0
							enemycreated=1
						end
					end
				end
				if enemycreated==0 then
					enemy[numobjects+1]={}
					enemy[numobjects+1].body=love.physics.newBody(world,xpos[a],ypos[a],1,0.01)
					enemy[numobjects+1].shape=love.physics.newCircleShape(enemy[numobjects+1].body,0,0,15)
					enemy[numobjects+1].shape:setData("enemy")
					enemy[numobjects+1].dead=0
					--compatibility with other functions
					numobjects=numobjects+1
					object[numobjects]="enemy"
				end
			end)
		end
	end
end
